/*
 * @Description: U9送货单
 * @Author: Ben Lin
 * @version:
 * @Date: 2024-06-19 20:34:27
 * @LastEditors: Ben Lin
 * @LastEditTime: 2024-10-23 20:48:14
 */

import { unref } from 'vue';
import { GetEnum, getEntity } from '/@/api/tigerapi/system';
import { useLocale } from '/@/locales/useLocale';
import { useI18n } from '/@/hooks/web/useI18n';
import { useModal } from '/@/components/Modal';
import { ActionItem, BasicColumn, FormSchema } from '/@/components/Table';
import { CustModalParams } from '/@/api/tigerapi/model/systemModel';
import { useForm } from '/@/components/Form/index';

const { t } = useI18n();
const { getLocale } = useLocale();
function _default() {
  const ActionColumn: BasicColumn = {
    width: 180,
    title: '操作',
    dataIndex: 'action',
    slots: { customRender: 'action' },
    fixed: 'right',
  };
  /**
   * @description: 工单管理的一些自定义方法
   * @return {*}
   */
  const methods = {
    /**
     * @description: 获取新增按钮的行为
     * @return {*}
     */
    CreateAction: (type: string, fnName: string) => {
      return {
        action: 'drawer', //drawer(打开左侧抽屉框) | go(跳转到新的页面)
      };
    },
    /**
     * @description: 操作字段自定义按钮
     * @return {*}
     */
    ActionItem: (params: Recordable<any>, data, ...args): ActionItem[] => {
      data.map((x) => {
        if (x.name == 'goDetail') {
          x.onClick = goDetail.bind(null, args[5], params);
          x.tooltip = '单据号';
        }
      });
      return data;
    },
    /**
     * @desc 初始化表单
     */
    GetUseForm: () => {
      return {
        forminfo: useForm({
          labelWidth: 120,
          schemas: woformSchema,
          actionColOptions: {
            span: 24,
          },
          showActionButtonGroup: false,
        }),
        woinfo: useForm({
          labelWidth: 120,
          schemas: woCfgformSchema,
          actionColOptions: {
            span: 24,
          },
          showActionButtonGroup: false,
        }),
        prodinfo: useForm({
          labelWidth: 120,
          schemas: prodCfgformSchema,
          actionColOptions: {
            span: 24,
          },
          showActionButtonGroup: false,
        }),
        tmpinfo: useForm({
          labelWidth: 120,
          schemas: prodCfgformSchema,
          actionColOptions: {
            span: 24,
          },
          showActionButtonGroup: false,
        }),
      };
    },
    /**
     * @description: 自定义方法
     * @param {string} type
     * @param {array} args
     * @return {*}
     */
    CustFunc: (param: CustModalParams) => {
      switch (param.cType) {
        case 'BIZ_MES_WO':
        case 'BIZ_MES_WO_Config':
          //   return getWoFns[param.FnName](param) as Promise<any>;
          break;
        default:
          return new Promise((resolve, reject) => {
            try {
              (e) => {};
              resolve(true);
            } catch {
              reject(false);
            } finally {
              // args[0][0]({ confirmLoading: false });
            }
          });
        // break;
      }
    },
    /**
     * @description: 获取多表单插槽列表
     * @return {*}
     */
    GetDtlSlots: (type: string) => {
      let result = [] as any[];
      switch (type) {
        case 'BIZ_MES_WO_Config':
          result = [
            { name: 'woinfo', slots: [], preIcons: {}, title: '工单信息' },
            {
              name: 'prodinfo',
              slots: ['addRot', 'setRot'],
              preIcons: { addRot: 'search|svg', setRot: 'config|svg' },
              title: '产品信息',
            },
            { name: 'rotinfo', slots: ['add'], preIcons: { add: 'search|svg' }, title: '工艺信息' },
          ];
          break;
        case 'BIZ_MES_WO':
          result = [
            {
              name: 'forminfo',
              slots: ['add', 'set'],
              preIcons: { add: 'search|svg', set: 'config|svg' }, //如果是多个表单，增加多个插槽。slots是弹出框按钮的插槽，preIcons是插槽对应的按钮图标
              title: '下发配置',
            },
          ];
          break;
      }
      return result;
    },
    /**
     * @description: 获取模态框应用列表
     * @return {*}
     */
    GetUseModals: () => {
      return {
        useModalData: {
          add: useModal(),
          set: useModal(),
          addRot: useModal(),
          setRot: useModal(),
        },
      };
    },
    /**
     * @description: 获取自定义数据
     * @return {*}
     */
    GetCustData: () => {
      return {
        isCustEl: {
          forminfo: false,
          woinfo: false,
          prodinfo: false,
          rotinfo: true,
        },
      };
    },
    /**
     * @description: 弹出选择框选择成功返回方法
     * @param {*} d
     * @param {*} u
     * @return {*}
     */
    GetSelectSuccess: (d, u) => {
      return {
        ROUTE_CODE: d.values['val'],
        // ID: d.values['id'],
        ROT_ID: d.values['id'],
      };
    },
    /**
     * @description: 打开弹出选择框
     * @param {Fn} openItemModal
     * @param {array} args
     * @return {*}
     */
    OpenSelectItem: (openItemModal: Fn, ...args) => {
      const slotName = args[0];
      const openRvModal = args[1];
      const selectVals = args[2];
      switch (slotName) {
        case 'addRot':
        case 'add':
          openItemModal(true, {
            title: '工艺路线列表',
            schemas: [
              {
                field: 'ROT_CODE',
                component: 'Input',
                label: '工艺路线编码',
                colProps: {
                  span: 12,
                },
              },
            ],
            ItemColumns: [
              {
                title: t('工艺路线编码'),
                dataIndex: 'ROT_CODE',
                resizable: true,
                sorter: true,
                width: 200,
              },
              {
                title: t('工艺路线名称'),
                dataIndex: 'ROT_NAME',
                resizable: true,
                sorter: true,
                width: 180,
              },
            ],
            tableName: 'MES_ROUTE',
            rowKey: 'ROT_CODE',
            returnFieldName: ['ROUTE_CODE', 'ROT_ID'], //返回值要赋值的字段名称
            searchInfo: { TABLE_NAME: 'MES_ROUTE' },
          });
          break;
        case 'set':
          openRvModal(true, { rotId: selectVals.value['ROUTE_CODE'], slotName: slotName });
          break;
        case 'setRot':
          break;
      }
    },
    /**
     * @description: 获取标题信息
     * @param {string} type
     * @return {*}
     */
    GetTitle: () => {
      return {
        importTitle: '工单计划导入' /* 打开模态窗口显示的标题 */,
      };
    },
  };

  /* 以下是内部方法，不export，供上面的方法调用 */

  /**
   * @description: 跳转到详情页面方法
   * @param {Fn} go
   * @return {*}
   */
  function goDetail(go: Fn, params: Recordable) {
    const id = {
      ID: params['record'].ID,
      CODE: params['record']['ORDER_NO'],
      Name: 'BIZ_U9_ASN_DTL',
      firstTabName: '送货单(U9)',
      secondTabName: '送货单SN', //'标签过程变量',
      firstTitle: '明细',
      secondTitle: '', //'过程变量',
      Tabs: [
        {
          name: '送货单(U9)',
          tableTitle: '明细',
          entityName: 'BIZ_U9_ASN_DTL',
          NeedInclude: true,
          key: 'BIZ_U9_ASN_DTL',
        },
        {
          name: '送货单SN',
          tableTitle: 'SN',
          entityName: 'BIZ_U9_ASN_SN',
          NeedInclude: true,
          key: 'BIZ_U9_ASN_SN',
        },
      ],
      pageTitle: '送货单(U9)详情', //详情页面标题
      contentStr: '这里是送货单(U9)明细管理页面，可以显示送货单(U9)的所有批次详情',
      detailName: `送货单[${params['record'].ORDER_NO}]批次详情`,
      keyFieldValues: { ORDER_NO: params['record']['ORDER_NO'] },
      colSlots: params['colSlots'].value,
      SessionName: 'BIZ_U9_ASN_DTL_update',
      ifSave: false,
    };
    // 将对象转换为JSON字符串并保存到sessionStorage
    sessionStorage.removeItem(`${id.SessionName}_params`);
    sessionStorage.setItem(`${id.SessionName}_params`, encodeURI(JSON.stringify(id)));
    go(`/BIZ_U9_ASN_DTL/${encodeURI(JSON.stringify({ sName: id.SessionName, Name: id.Name }))}`);
  }

  const woformSchema: FormSchema[] = [
    {
      field: 'PLAN_QTY',
      label: '工单数量',
      component: 'Input',
      required: true,
      colProps: {
        span: 24,
      },
      dynamicDisabled: ({ values }) => {
        return true;
      },
    },
    {
      field: 'RELEASE_QTY',
      label: '工单下发数量',
      component: 'Input',
      required: true,
      colProps: {
        span: 24,
      },
    },
    {
      label: '实际产线',
      field: 'ACT_LINE',
      component: 'ApiSelect',
      required: true,
      colProps: {
        span: 24,
      },
      componentProps: {
        api: getEntity,
        params: { entityName: 'MES_LINE', sqlcmd: ' 1=1 ', order: '' },
        resultField: 'Data.Items',
        labelField: 'LINE_NAME',
        valueField: 'LINE_CODE',
      },
    },
    {
      field: 'IfToCust',
      component: 'Switch',
      label: '是否保存工艺路线到客户',
      defaultValue: true,
      colProps: {
        span: 8,
      },
      labelWidth: 200,
    },
    // {
    //   label: '工艺路线',
    //   field: 'ROUTE_CODE',
    //   component: 'Input',
    //   required: true,
    //   colProps: {
    //     span: 22,
    //   },
    // },
    // {
    //   field: 'add',
    //   component: 'Input',
    //   label: '1',
    //   colSlot: 'add',
    //   defaultValue: 'MES_ROUTE',
    //   colProps: {
    //     span: 1,
    //   },
    // },
    // {
    //   field: 'set',
    //   component: 'Input',
    //   label: '1',
    //   colSlot: 'set',
    //   defaultValue: 'MES_ROUTE',
    //   colProps: {
    //     span: 1,
    //   },
    // },
  ];

  const woCfgformSchema: FormSchema[] = [
    {
      field: 'ORDER_NO',
      component: 'Input',
      label: '工单号',
      colProps: {
        span: 8,
      },
      componentProps: {
        placeholder: '请输入工单号',
        onChange: (e: any) => {
          console.log(e);
        },
      },
      dynamicDisabled: true,
    },
    {
      field: 'ORDER_TYPE',
      component: 'ApiSelect',
      label: '工单类型',
      colProps: {
        span: 8,
      },
      defaultValue: 0,
      componentProps: {
        api: GetEnum,
        params: { name: 'BIZ_MES_WO+ORDER_TYPEs' },
        resultField: 'Data',
        labelField: unref(getLocale) == 'zh_CN' ? 'Desc' : 'Name',
        valueField: 'Value',
        placeholder: '请选择工单类型',
      },
      dynamicDisabled: true,
    },
    {
      field: 'PLAN_QTY',
      component: 'Input',
      label: '计划数量',
      colProps: {
        span: 8,
      },
      dynamicDisabled: true,
    },
  ];

  const prodCfgformSchema: FormSchema[] = [
    {
      field: 'ITEM_CODE',
      component: 'Input',
      label: '物料编码',
      required: true,
      colProps: {
        span: 12,
      },
      componentProps: {
        placeholder: '请输入物料编码',
        onChange: (e: any) => {
          console.log(e);
        },
      },
      dynamicDisabled: true,
    },
    {
      field: 'ITEM_TYPE',
      component: 'Input',
      label: '物料类型',
      colProps: {
        span: 12,
      },
    },
    {
      label: '工艺路线',
      field: 'ROUTE_CODE',
      component: 'Input',
      required: true,
      colProps: {
        span: 12,
      },
    },
    {
      field: 'addRot',
      component: 'Input',
      label: '1',
      colSlot: 'addRot',
      defaultValue: 'MES_ROUTE',
      colProps: {
        span: 1,
      },
    },
    {
      field: 'setRot',
      component: 'Input',
      label: '1',
      colSlot: 'setRot',
      defaultValue: 'MES_ROUTE',
      colProps: {
        span: 1,
      },
    },
    {
      label: '工艺路线',
      field: 'ROT_ID',
      component: 'Input',
      show: false,
      colProps: {
        span: 12,
      },
    },
    // {
    //   field: 'fieldsc',
    //   component: 'Upload',
    //   label: '打印模板',
    //   colProps: {
    //     span: 10,
    //   },
    //   rules: [{ required: true, message: '请选择上传文件' }],
    //   componentProps: {
    //     api: uploadApi,
    //     multiple: false,
    //   },
    // },
  ];

  return [methods, ActionColumn];
}

export default _default;
